# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/islhd/supplier/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/islhd/supplier/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Islhd\\Supplier\\": "packages/islhd/supplier/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Islhd\Supplier\Providers\SupplierServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Supplier'  => Islhd\Supplier\Facades\Supplier::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Islhd\\SupplierTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Islhd\Supplier\Providers\SupplierServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Islhd\Supplier\Providers\SupplierServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Islhd\Supplier\Providers\SupplierServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/supplier/{modulename}

**User**

    http://path-to-route-folder/user/supplier/{modulename}

**Public**

    http://path-to-route-folder/suppliers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/supplier/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/supplier/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/supplier/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/supplier/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/supplier/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/supplier/{modulename}/{slug}
    METHOD: GET