<?php

namespace Islhd\Supplier\Policies;

use Litepie\User\Contracts\UserPolicy;
use Islhd\Supplier\Models\Contract;

class ContractPolicy
{

    /**
     * Determine if the given user can view the contract.
     *
     * @param UserPolicy $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function view(UserPolicy $user, Contract $contract)
    {
        if ($user->canDo('supplier.contract.view') && $user->isAdmin()) {
            return true;
        }

        return $contract->user_id == user_id() && $contract->user_type == user_type();
    }

    /**
     * Determine if the given user can create a contract.
     *
     * @param UserPolicy $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('supplier.contract.create');
    }

    /**
     * Determine if the given user can update the given contract.
     *
     * @param UserPolicy $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function update(UserPolicy $user, Contract $contract)
    {
        if ($user->canDo('supplier.contract.edit') && $user->isAdmin()) {
            return true;
        }

        return $contract->user_id == user_id() && $contract->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given contract.
     *
     * @param UserPolicy $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Contract $contract)
    {
        return $contract->user_id == user_id() && $contract->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given contract.
     *
     * @param UserPolicy $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Contract $contract)
    {
        if ($user->canDo('supplier.contract.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contract.
     *
     * @param UserPolicy $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Contract $contract)
    {
        if ($user->canDo('supplier.contract.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
