<?php

namespace Islhd\Supplier\Providers;

use Illuminate\Support\ServiceProvider;

class SupplierServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'supplier');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'supplier');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSupplier();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSupplier()
    {
        $this->app->bind('supplier', function($app) {
            return new Supplier($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Supplier', 'Lavalite\Supplier\Facades\Supplier');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('islhd.supplier', function ($app) {
            return $this->app->make('Islhd\Supplier\Supplier');
        });

        // Bind Supplier to repository
        $this->app->bind(
            'Islhd\Supplier\Interfaces\SupplierRepositoryInterface',
            \Islhd\Supplier\Repositories\Eloquent\SupplierRepository::class
        );        // Bind Contract to repository
        $this->app->bind(
            'Islhd\Supplier\Interfaces\ContractRepositoryInterface',
            \Islhd\Supplier\Repositories\Eloquent\ContractRepository::class
        );

        $this->app->register(\Islhd\Supplier\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Islhd\Supplier\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and supplier's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'islhd.supplier'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSupplier::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['islhd.supplier'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('islhd/supplier.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/supplier')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/supplier')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
